@@ -13,6 +13,7 @@ from .models import (
     GlueBackend,
     glue_backends,
 )
+from .utils import validate_crawl_filters
 
 
 class DateTimeEncoder(json.JSONEncoder):
@@ -326,6 +327,12 @@ class GlueResponse(BaseResponse):
         self.glue_backend.delete_crawler(name)  # type: ignore[arg-type]
         return ""
 
+    def list_crawls(self) -> str:
+        crawler_name = self.parameters.get("CrawlerName")
+        filters = validate_crawl_filters(self.parameters.get("Filters", []))
+        crawls = self.glue_backend.list_crawls(crawler_name, filters)[0]
+        return json.dumps({"Crawls": [crawl.as_dict() for crawl in crawls]})
+
     def create_job(self) -> str:
         name = self._get_param("Name")
         description = self._get_param("Description")
@@ -818,6 +825,11 @@ class GlueResponse(BaseResponse):
         dev_endpoint = self.glue_backend.get_dev_endpoint(endpoint_name)
         return json.dumps({"DevEndpoint": dev_endpoint.as_dict()})
 
+    def delete_dev_endpoint(self) -> str:
+        endpoint_name = self._get_param("EndpointName")
+        self.glue_backend.delete_dev_endpoint(endpoint_name)
+        return json.dumps({})
+
     def create_connection(self) -> str:
         catalog_id = self._get_param("CatalogId")
         connection_input = self._get_param("ConnectionInput")
@@ -910,3 +922,14 @@ class GlueResponse(BaseResponse):
         )
 
         return json.dumps(response, cls=DateTimeEncoder)
+
+    def delete_resource_policy(self) -> str:
+        params = json.loads(self.body)
+        policy_hash_condition = params.get("PolicyHashCondition")
+        resource_arn = params.get("ResourceArn")
+        self.glue_backend.delete_resource_policy(
+            resource_arn=resource_arn,
+            policy_hash_condition=policy_hash_condition,
+        )
+
+        return "{}"
