@@ -7,8 +7,14 @@ from moto.backup.models import BackupBackend, backup_backends
 from moto.clouddirectory import CloudDirectoryBackend, clouddirectory_backends
 from moto.cloudfront.models import CloudFrontBackend, cloudfront_backends
 from moto.cloudwatch.models import CloudWatchBackend, cloudwatch_backends
+from moto.comprehend.models import ComprehendBackend, comprehend_backends
+from moto.connectcampaigns.models import (
+    ConnectCampaignServiceBackend,
+    connectcampaigns_backends,
+)
 from moto.core.base_backend import BackendDict, BaseBackend
 from moto.core.exceptions import RESTError
+from moto.directconnect.models import DirectConnectBackend, directconnect_backends
 from moto.dms.models import DatabaseMigrationServiceBackend, dms_backends
 from moto.dynamodb.models import DynamoDBBackend, dynamodb_backends
 from moto.ec2 import ec2_backends
@@ -68,6 +74,10 @@ class ResourceGroupsTaggingAPIBackend(BaseBackend):
     def s3_backend(self) -> S3Backend:
         return s3_backends[self.account_id][self.partition]
 
+    @property
+    def directconnect_backend(self) -> DirectConnectBackend:
+        return directconnect_backends[self.account_id][self.region_name]
+
     @property
     def dms_backend(self) -> DatabaseMigrationServiceBackend:
         return dms_backends[self.account_id][self.region_name]
@@ -182,6 +192,13 @@ class ResourceGroupsTaggingAPIBackend(BaseBackend):
             return workspacesweb_backends[self.account_id][self.region_name]
         return None
 
+    @property
+    def comprehend_backend(self) -> Optional[ComprehendBackend]:
+        # aws Comprehend has limited region availability
+        if self.region_name in comprehend_backends[self.account_id].regions:
+            return comprehend_backends[self.account_id][self.region_name]
+        return None
+
     @property
     def kafka_backend(self) -> KafkaBackend:
         return kafka_backends[self.account_id][self.region_name]
@@ -210,6 +227,13 @@ class ResourceGroupsTaggingAPIBackend(BaseBackend):
     def cloudwatch_backend(self) -> CloudWatchBackend:
         return cloudwatch_backends[self.account_id][self.region_name]
 
+    @property
+    def connectcampaigns_backend(self) -> Optional[ConnectCampaignServiceBackend]:
+        # Connect Campaigns service has limited region availability
+        if self.region_name in connectcampaigns_backends[self.account_id].regions:
+            return connectcampaigns_backends[self.account_id][self.region_name]
+        return None
+
     def _get_resources_generator(
         self,
         tag_filters: Optional[List[Dict[str, Any]]] = None,
@@ -299,6 +323,31 @@ class ResourceGroupsTaggingAPIBackend(BaseBackend):
 
                 yield {"ResourceARN": f"{vault.backup_vault_arn}", "Tags": tags}
 
+        # Comprehend
+        if self.comprehend_backend:
+            if not resource_type_filters or "comprehend" in resource_type_filters:
+                for document_classifier in self.comprehend_backend.classifiers.values():
+                    tags = self.comprehend_backend.tagger.list_tags_for_resource(
+                        document_classifier.arn
+                    )["Tags"]
+                    if not tags or not tag_filter(tags):
+                        continue
+                    yield {
+                        "ResourceARN": f"{document_classifier.arn}",
+                        "Tags": tags,
+                    }
+
+                for entity_recognizer in self.comprehend_backend.recognizers.values():
+                    tags = self.comprehend_backend.tagger.list_tags_for_resource(
+                        entity_recognizer.arn
+                    )["Tags"]
+                    if not tags or not tag_filter(tags):
+                        continue
+                    yield {
+                        "ResourceARN": f"{entity_recognizer.arn}",
+                        "Tags": tags,
+                    }
+
         # S3
         if (
             not resource_type_filters
@@ -388,6 +437,47 @@ class ResourceGroupsTaggingAPIBackend(BaseBackend):
                             "Tags": tags,
                         }
 
+        # Connect Campaigns v1
+        if self.connectcampaigns_backend:
+            if not resource_type_filters or "connectcampaigns" in resource_type_filters:
+                connectcampaigns_backend: ConnectCampaignServiceBackend = (
+                    connectcampaigns_backends[self.account_id][self.region_name]
+                )
+                for campaign in connectcampaigns_backend.campaigns.values():
+                    tags = connectcampaigns_backend.tagger.list_tags_for_resource(
+                        campaign.arn
+                    )["Tags"]
+                    if not tags or not tag_filter(tags):
+                        continue
+                    yield {"ResourceARN": f"{campaign.arn}", "Tags": tags}
+
+        # Direct Connect
+        if self.directconnect_backend:
+            if not resource_type_filters or "directconnect" in resource_type_filters:
+                directconnect_backend = directconnect_backends[self.account_id][
+                    self.region_name
+                ]
+
+                # Connections
+                for connection in directconnect_backend.connections.values():
+                    tags = directconnect_backend.tagger.list_tags_for_resource(
+                        connection.connection_id
+                    )["Tags"]
+                    tags = format_tag_keys(tags, ["key", "value"])
+                    if not tags or not tag_filter(tags):
+                        continue
+                    yield {"ResourceARN": f"{connection.connection_id}", "Tags": tags}
+
+                # LAGs
+                for lag in directconnect_backend.lags.values():
+                    tags = directconnect_backend.tagger.list_tags_for_resource(
+                        lag.lag_id
+                    )["Tags"]
+                    tags = format_tag_keys(tags, ["key", "value"])
+                    if not tags or not tag_filter(tags):
+                        continue
+                    yield {"ResourceARN": f"{lag.lag_id}", "Tags": tags}
+
         # DMS
         if not resource_type_filters or "dms:endpoint" in resource_type_filters:
             for endpoint in self.dms_backend.endpoints.values():
@@ -433,6 +523,14 @@ class ResourceGroupsTaggingAPIBackend(BaseBackend):
                         continue
                     yield {"ResourceARN": f"{task.task_arn}", "Tags": tags}
 
+        if not resource_type_filters or "ecs:task-definition" in resource_type_filters:
+            for task_definition_dict in self.ecs_backend.task_definitions.values():
+                for task_definition in task_definition_dict.values():
+                    tags = format_tag_keys(task_definition.tags, ["key", "value"])
+                    if not tag_filter(tags):
+                        continue
+                    yield {"ResourceARN": f"{task_definition.arn}", "Tags": tags}
+
         # EC2 Resources
         ec2_resource_types = {
             "ec2:image": self.ec2_backend.amis.values(),
@@ -1212,7 +1310,7 @@ class ResourceGroupsTaggingAPIBackend(BaseBackend):
         self, resource_arns: List[str], tags: Dict[str, str]
     ) -> Dict[str, Dict[str, Any]]:
         """
-        Only DynamoDB, Logs, RDS, and SageMaker resources are currently supported
+        Only DynamoDB, EFS, Lambda Logs, RDS, and SageMaker resources are currently supported
         """
         missing_resources = []
         missing_error: Dict[str, Any] = {
@@ -1249,12 +1347,44 @@ class ResourceGroupsTaggingAPIBackend(BaseBackend):
                 self.sagemaker_backend.add_tags(
                     arn, TaggingService.convert_dict_to_tags_input(tags)
                 )
+            elif arn.startswith(f"arn:{get_partition(self.region_name)}:lambda:"):
+                self.lambda_backend.tag_resource(arn, tags)
+            elif arn.startswith(
+                f"arn:{get_partition(self.region_name)}:elasticfilesystem:"
+            ):
+                resource_id = arn.split("/")[-1]
+                self.efs_backend.tag_resource(
+                    resource_id, TaggingService.convert_dict_to_tags_input(tags)
+                )
             else:
                 missing_resources.append(arn)
         return {arn: missing_error for arn in missing_resources}
 
-    # def untag_resources(self, resource_arn_list, tag_keys):
-    #     return failed_resources_map
+    def untag_resources(
+        self, resource_arn_list: List[str], tag_keys: List[str]
+    ) -> Dict[str, Dict[str, Any]]:
+        """
+        Only EFS and Lambda resources are currently supported
+        """
+        missing_resources = []
+        missing_error: Dict[str, Any] = {
+            "StatusCode": 404,
+            "ErrorCode": "InternalServiceException",
+            "ErrorMessage": "Service not yet supported",
+        }
+
+        for arn in resource_arn_list:
+            if arn.startswith(f"arn:{get_partition(self.region_name)}:lambda:"):
+                self.lambda_backend.untag_resource(arn, tag_keys)
+            elif arn.startswith(
+                f"arn:{get_partition(self.region_name)}:elasticfilesystem:"
+            ):
+                resource_id = arn.split("/")[-1]
+                self.efs_backend.untag_resource(resource_id, tag_keys)
+            else:
+                missing_resources.append(arn)
+
+        return {arn: missing_error for arn in missing_resources}
 
 
 resourcegroupstaggingapi_backends = BackendDict(
