@@ -132,11 +132,25 @@ class RawMessage(BaseModel):
 
 class SESQuota(BaseModel):
     def __init__(self, sent: int):
-        self.sent = sent
+        self.sent_last24_hours = sent
+        self.max24_hour_send = 200
+        self.max_send_rate = 1
+
+
+class ReceiptRuleSet(BaseModel):
+    def __init__(self, name: str):
+        self.name = name
+        self.created_timestamp = datetime.datetime.now(
+            datetime.timezone.utc
+        ).isoformat()
+        self.rules: List[Dict[str, Any]] = []
 
     @property
-    def sent_past_24(self) -> int:
-        return self.sent
+    def metadata(self) -> dict[str, str]:
+        return {
+            "CreatedTimestamp": self.created_timestamp,
+            "Name": self.name,
+        }
 
 
 class ConfigurationSet(BaseModel):
@@ -205,7 +219,7 @@ class SESBackend(BaseBackend):
         self.event_destinations: Dict[str, int] = {}
         self.identity_mail_from_domains: Dict[str, Dict[str, Any]] = {}
         self.templates: Dict[str, Dict[str, str]] = {}
-        self.receipt_rule_set: Dict[str, List[Dict[str, Any]]] = {}
+        self.receipt_rule_set: Dict[str, ReceiptRuleSet] = {}
         self.dkim_tokens: Dict[str, List[str]] = {}
 
     def _is_verified_address(self, source: str) -> bool:
@@ -435,7 +449,13 @@ class SESBackend(BaseBackend):
     ) -> Dict[str, Dict[str, Any]]:
         response: Dict[str, Dict[str, Any]] = {}
         for identity in identities:
-            response[identity] = self.sns_topics.get(identity, {})
+            config = self.sns_topics.get(identity, {})
+            response[identity] = {
+                "ForwardingEnabled": config.get("feedback_forwarding_enabled", True),
+                "HeadersInBounceNotificationsEnabled": False,
+                "HeadersInComplaintNotificationsEnabled": False,
+                "HeadersInDeliveryNotificationsEnabled": False,
+            }
         return response
 
     def set_identity_feedback_forwarding_enabled(
@@ -620,18 +640,18 @@ class SESBackend(BaseBackend):
     def create_receipt_rule_set(self, rule_set_name: str) -> None:
         if self.receipt_rule_set.get(rule_set_name) is not None:
             raise AlreadyExists(f"Rule set already exists: {rule_set_name}")
-        self.receipt_rule_set[rule_set_name] = []
+        self.receipt_rule_set[rule_set_name] = ReceiptRuleSet(name=rule_set_name)
 
     def create_receipt_rule(self, rule_set_name: str, rule: Dict[str, Any]) -> None:
         rule_set = self.receipt_rule_set.get(rule_set_name)
         if rule_set is None:
             raise RuleSetDoesNotExist(f"Rule set does not exist: {rule_set_name}")
-        if rule in rule_set:
+        if rule in rule_set.rules:
             raise AlreadyExists(f"Rule already exists: {rule['name']}")
-        rule_set.append(rule)
+        rule_set.rules.append(rule)
         self.receipt_rule_set[rule_set_name] = rule_set
 
-    def describe_receipt_rule_set(self, rule_set_name: str) -> List[Dict[str, Any]]:
+    def describe_receipt_rule_set(self, rule_set_name: str) -> ReceiptRuleSet:
         rule_set = self.receipt_rule_set.get(rule_set_name)
 
         if rule_set is None:
@@ -647,7 +667,7 @@ class SESBackend(BaseBackend):
         if rule_set is None:
             raise RuleSetDoesNotExist(f"Rule set does not exist: {rule_set_name}")
 
-        for receipt_rule in rule_set:
+        for receipt_rule in rule_set.rules:
             if receipt_rule["name"] == rule_name:
                 return receipt_rule
 
@@ -659,9 +679,9 @@ class SESBackend(BaseBackend):
         if rule_set is None:
             raise RuleSetDoesNotExist(f"Rule set does not exist: {rule_set_name}")
 
-        for i, receipt_rule in enumerate(rule_set):
+        for i, receipt_rule in enumerate(rule_set.rules):
             if receipt_rule["name"] == rule["name"]:
-                rule_set[i] = rule
+                rule_set.rules[i] = rule
                 break
         else:
             raise RuleDoesNotExist(f"Rule does not exist: {rule['name']}")
@@ -703,27 +723,32 @@ class SESBackend(BaseBackend):
     ) -> Dict[str, Dict[str, str]]:
         if identities is None:
             identities = []
-
         attributes_by_identity = {}
         for identity in identities:
             if identity in (self.domains + self.addresses):
-                attributes_by_identity[identity] = self.identity_mail_from_domains.get(
-                    identity
-                ) or {"behavior_on_mx_failure": "UseDefaultValue"}
-
+                value = self.identity_mail_from_domains.get(identity, {})
+                mail_from_domain = value.get("mail_from_domain")
+                attributes_by_identity[identity] = {
+                    "MailFromDomain": mail_from_domain,
+                    "MailFromDomainStatus": "Success" if mail_from_domain else None,
+                    "BehaviorOnMXFailure": value.get(
+                        "behavior_on_mx_failure", "UseDefaultValue"
+                    ),
+                }
         return attributes_by_identity
 
     def get_identity_verification_attributes(
         self, identities: Optional[List[str]] = None
-    ) -> Dict[str, str]:
+    ) -> Dict[str, Dict[str, str]]:
         if identities is None:
             identities = []
-
-        attributes_by_identity: Dict[str, str] = {}
+        attributes_by_identity = {}
         for identity in identities:
             if identity in (self.domains + self.addresses):
-                attributes_by_identity[identity] = "Success"
-
+                attributes_by_identity[identity] = {
+                    "VerificationStatus": "Success",
+                    "VerificationToken": "ILQMESfEW0p6i6gIJcEWvO65TP5hg6B99hGFZ2lxrIs=",
+                }
         return attributes_by_identity
 
     def update_configuration_set_reputation_metrics_enabled(
